# CHANGELOG

## [v0.4.1] - 2025.11.14
- fixed:
  - incorrect trailing newline insertion
  
## [v0.4.0] - 2025.10.17
- added:
  - a function to replace, add, or delete a definition
- changed:
  - query for top level function, recursive function, and all regular functions are consolidated into one query
  

## [v0.3.4] - 2025.10.13
- fixed:
  - incorrect request insertion when IML code has no trailing newline at the end

## [v0.3.3] - 2025.10.07
- added:
  - detect nested recursive function

## [v0.3.0] - 2025.09.26
- multi-pattern query optimization
- add types (dataclasses) for captures

## [v0.2.0] - 2025.09.23
- IML code manipulation
  - remove decomp / verify / instance requests from IML code
  - attach decomp / verify / instance requests to IML code
- basic linting: detect nested measure attributes
- refactor
  - reorganize query.py into focused modules
  - better test coverage
- example script


## [v0.1.0] - 2025.09.19

- grammar
- basic queries
- basic API bundled with queries
